# generated by datamodel-codegen:
#   filename:  config.json

from __future__ import annotations

from dataclasses import dataclass, field
from enum import Enum
from typing import Any, Dict, List, Optional


@dataclass
class AwsEmf:
    namespace: str
    high_resolution_metrics: bool | None = False
    """
    https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/publishingMetrics.html#high-resolution-metrics
    """
    dimensions: dict[str, str] | None = None
    """
    Dimension name and value to set in a key/value format.
    """
    enabled: bool | None = None


@dataclass
class Template:
    """
    Allows to set specific templates for email and sms
    """

    email: str | None = None
    """
    Optional - Path to a template for SNS Email messages
    """
    sms: str | None = None
    """
    Optional - Path to a template for SNS SMS messages
    """


@dataclass
class SnsTopicChannel:
    topic_arn: str
    """
    ARN of the SNS topic.
    """
    role_arn: str | None = None
    """
    Optional - Use IAM role to publish messages using another IAM role
    """
    ignore_errors: bool | None = None
    """
    Prevents exception if true when an exception occurs.
    """
    template: Template | None = None
    """
    Allows to set specific templates for email and sms
    """


@dataclass
class Prometheus:
    enabled: bool | None = None


@dataclass
class ClusterMetrics:
    prometheus: Prometheus | None = None
    aws_emf: AwsEmf | None = None


Regexes = list[str]


class BackupStyle(Enum):
    cfn_kafka_admin = "cfn-kafka-admin"
    kafka_topics_sh = "kafka-topics.sh"


@dataclass
class AssumeRole:
    RoleArn: str
    """
    Optional - IAM Role ARN to assume
    """
    RoleSessionName: str | None = "kafka-overwatch@s3"
    """
    Optional - Name of the session to use
    """
    ExternalId: str | None = None
    """
    Optional - External ID to use when assuming a role
    """


@dataclass
class IamOverride:
    """
    Optional - IAM profile/settings override to use. Defaults to SDK settings.
    """

    ProfileName: str | None = None
    """
    Optional - Use IAM profile to publish messages using another IAM profile
    """
    AssumeRole: AssumeRole | None = None


ClusterScanIntervalInSeconds = int


@dataclass
class Global:
    """
    Global settings. Apply to all clusters
    """

    ClusterScanIntervalInSeconds: ClusterScanIntervalInSeconds


@dataclass
class AwsEmfModel:
    log_group_name: str | None = "kafka/cluster/overwatch/metrics"
    """
    override log group name to publish metrics to. Importance: High
    """
    service_name: str | None = None
    """
    override value for EMF Service name. Importance: Low
    """
    watcher_config: AwsEmf | None = None


@dataclass
class NotificationChannels:
    """
    Channels to send notifications to when reports have been generated.
    """

    sns: dict[str, SnsTopicChannel] | None = None


@dataclass
class S3Output:
    BucketName: str | None = None
    """
    Name of the S3 bucket
    """
    PrefixKey: str | None = ""
    """
    Path in the bucket.
    """
    IamOverride: IamOverride | None = None


@dataclass
class ReportingConfig:
    """
    Configure reporting output. Applies to all clusters.
    """

    evaluation_period_in_seconds: int | None = 60
    """
    Time to wait before generating reports
    """
    S3: S3Output | None = None
    local: str | None = "/tmp/kafka-overwatch-reports/"
    """
    Local directory to store the reports to.
    """
    kafka: dict[str, Any] | None = None
    """
    Configuration to persist reports into Kafka. Not yet implemented.
    """


@dataclass
class GatewayConfiguration:
    gateway_config: dict[str, Any] | None = None
    reporting_config: ReportingConfig | None = None
    topic_include_regexes: Regexes | None = None
    topic_exclude_regexes: Regexes | None = None
    metrics: ClusterMetrics | None = None
    """
    Configure metrics export for the cluster
    """


@dataclass
class ClusterTopicBackupConfig:
    enabled: bool | None = False
    """
    Enable/disable backup of the topics configuration
    """
    S3: S3Output | None = None
    """
    Enables exports to be sent to S3.
    """
    BackupStyles: list[BackupStyle] | None = field(
        default_factory=lambda: [BackupStyle.kafka_topics_sh]
    )
    """
    List the types of backups you want to generate.
    """


@dataclass
class ClusterConfiguration:
    cluster_config: dict[str, Any]
    """
    Configuration as documented in https://github.com/confluentinc/librdkafka/blob/master/CONFIGURATION.md
    """
    reporting_config: ReportingConfig
    cluster_scan_interval_in_seconds: ClusterScanIntervalInSeconds | None = 60
    """
    Overrides the global setting
    """
    topics_backup_config: ClusterTopicBackupConfig | None = None
    awareness_topic: str | None = "_overwatchAwareness"
    """
    Name of a topic that the Overwatch will subscribe to. This allows multiple instances of the overwatch to be aware and disable features that shouldn't be distributed
    """
    topic_include_regexes: Regexes | None = None
    topic_exclude_regexes: Regexes | None = None
    metrics: ClusterMetrics | None = None
    """
    Configure metrics export for the cluster
    """


@dataclass
class KafkaOverwatchInputConfiguration:
    """
    Specification for Kafka topics/partitions hunter service
    """

    global_: Global | None = None
    """
    Global settings. Apply to all clusters
    """
    clusters: dict[str, ClusterConfiguration] | None = None
    """
    Kafka clusters to monitor and report on the partitions usage
    """
    gateways: dict[str, GatewayConfiguration] | None = None
    """
    Gateways to monitor and import the vClusters from the partitions usage
    """
    prometheus: Any | None = None
    notification_channels: NotificationChannels | None = None
    aws_emf: AwsEmfModel | None = None
